@@ -3,28 +3,25 @@ package collector
 import (
 	"encoding/json"
 	"fmt"
+	"log/slog"
 	"strings"
 
-	"github.com/go-kit/log"
-	"github.com/go-kit/log/level"
 	"github.com/prometheus/client_golang/prometheus"
 )
 
-var (
-	pimSubsystem = "pim"
-)
+const pimSubsystem = "pim"
 
 func init() {
 	registerCollector(pimSubsystem, disabledByDefault, NewPIMCollector)
 }
 
 type pimCollector struct {
-	logger       log.Logger
+	logger       *slog.Logger
 	descriptions map[string]*prometheus.Desc
 }
 
 // NewPIMCollector collects PIM metrics, implemented as per the Collector interface.
-func NewPIMCollector(logger log.Logger) (Collector, error) {
+func NewPIMCollector(logger *slog.Logger) (Collector, error) {
 	return &pimCollector{logger: logger, descriptions: getPIMDesc()}, nil
 }
 
@@ -51,7 +48,7 @@ func (c *pimCollector) Update(ch chan<- prometheus.Metric) error {
 	return nil
 }
 
-func processPIMNeighbors(ch chan<- prometheus.Metric, jsonPIMNeighbors []byte, logger log.Logger, pimDesc map[string]*prometheus.Desc) error {
+func processPIMNeighbors(ch chan<- prometheus.Metric, jsonPIMNeighbors []byte, logger *slog.Logger, pimDesc map[string]*prometheus.Desc) error {
 	var jsonMap map[string]json.RawMessage
 	if err := json.Unmarshal(jsonPIMNeighbors, &jsonMap); err != nil {
 		return fmt.Errorf("cannot unmarshal pim neighbors json: %s", err)
@@ -67,13 +64,13 @@ func processPIMNeighbors(ch chan<- prometheus.Metric, jsonPIMNeighbors []byte, l
 			if err := json.Unmarshal(ifaceData, &neighbors); err != nil {
 				return fmt.Errorf("cannot unmarshal neighbor json: %s", err)
 			}
-			for neighborIp, neighborData := range neighbors {
+			for neighborIP, neighborData := range neighbors {
 				neighborCount++
 				if uptimeSec, err := parseHMS(neighborData.UpTime); err != nil {
-					level.Error(logger).Log("msg", "cannot parse neighbor uptime", "uptime", neighborData.UpTime, "err", err)
+					logger.Error("cannot parse neighbor uptime", "uptime", neighborData.UpTime, "err", err)
 				} else {
 					// The labels are "vrf", "iface", "neighbor"
-					neighborLabels := []string{strings.ToLower(vrfName), strings.ToLower(ifaceName), neighborIp}
+					neighborLabels := []string{strings.ToLower(vrfName), strings.ToLower(ifaceName), neighborIP}
 					newGauge(ch, pimDesc["upTime"], float64(uptimeSec), neighborLabels...)
 				}
 
